@@ -11,5 +11,5 @@ typedef struct S_LCSS_RES
     int n;
 } LCSS_RES;
 
-LCSS_RES _lcss(char* s, char* t);
+LCSS_RES _lcss(char* s, char* t, int min);
 void _free_res(LCSS_RES res);
